@@ -16,12 +16,43 @@ prog="$(basename $0)"
 [ -z "$SETCOLOR_NORMAL"  ] && SETCOLOR_NORMAL="echo -en \\033[0;39m"
 BOOTUP="color"
 
+#
+msg_are_u_sure_u_want_to_continue='Are you sure you want to continue?'
+msg_you_have_to_enter_yes_or_no="You have to enter 'y', 'yes', 'n' or 'no'. Please enter it again!"
+msg_do_you_want_to_make_it_bootable="Do you want to mark it as bootable ?"
+
 #
 USAGE() {
    echo "Usage: $prog partition_device"
    echo "Ex:" 
-   echo "To make /dev/sdc1 bootable on Linux:"
-   echo "  $prog /dev/sdc1"
+   echo "To make /dev/sde1 bootable on Linux:"
+   echo "  $prog /dev/sde1"
+}
+#
+to_continue_or_not() {
+  local prompt_msg="$1"
+  continue_choice=""
+  while [ -z "$continue_choice" ]; do
+    [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
+    echo "$prompt_msg"
+    [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+    echo -n "[y/n] "
+    read continue_choice 
+    case "$continue_choice" in
+         y|Y|[yY][eE][sS])
+            echo "OK! Let's do it!" ;;
+         n|N|[nN][oO])
+            echo "Program terminated!"
+            exit 1
+            ;;
+         *)
+            [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
+            echo "$msg_you_have_to_enter_yes_or_no!"
+            [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
+            echo "--------------------------------------------"
+            ;;
+    esac
+  done
 }
 
 #
@@ -86,16 +117,9 @@ echo "Machine: $dev_model_shown:"
 [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
 fdisk -l $target_disk
 echo "--------------------------------------------"
-echo "Are you sure you want to continue ?"
-echo -n "[Y/n] "
-read continue_ans
-case "$continue_ans" in
-  n|N|[nN][oO])
-     echo "Program terminated!"
-     exit 1
-     ;;
-esac
 
+to_continue_or_not "$msg_are_u_sure_u_want_to_continue"
+echo "--------------------------------------------"
 
 # 0. Check if partition is a FAT partition
 # parted -s /dev/hda1 print
@@ -130,48 +154,20 @@ if [ "$bootable" != "*" ]; then
   echo $dev_model_shown:
   fdisk -l $target_disk
   echo "--------------------------------------------"
-  [ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-  echo "Do you want to mark it as bootable ?"
-  [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-  echo -n "[Y/n] "
-  read make_boot_ans
-  case "$make_boot_ans" in
-    n|N|[nN][oO])
-       echo "Program terminated!"
-       exit 1
-       ;;
-  esac
+  to_continue_or_not "$msg_do_you_want_to_make_it_bootable"
   echo "Running: parted -s $target_disk set $pt_dev_no boot on"
   parted -s $target_disk set $pt_dev_no boot on
+  echo "--------------------------------------------"
 fi
 
 # 3. MBR
-[ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-echo "Do you want to install mbr on $target_disk $on_this_machine ?"
-[ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-echo -n "[Y/n] "
-read make_mbr_ans
-case "$make_mbr_ans" in
-  n|N|[nN][oO])
-     echo "Program terminated!"
-     exit 1
-     ;;
-esac
+to_continue_or_not "Do you want to install mbr on $target_disk $on_this_machine ?"
 echo "Running: cat ../mbr/mbr.bin > $target_disk"
 cat ../mbr/mbr.bin > $target_disk
 
+echo "--------------------------------------------"
 # 4.
-[ "$BOOTUP" = "color" ] && $SETCOLOR_WARNING
-echo "Do you want to install the SYSLINUX bootloader on $target_part $on_this_machine ?"
-[ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
-echo -n "[Y/n] "
-read make_syslinux_ans
-case "$make_syslinux_ans" in
-  n|N|[nN][oO])
-     echo "Program terminated!"
-     exit 1
-     ;;
-esac
+to_continue_or_not "Do you want to install the SYSLINUX bootloader on $target_part $on_this_machine ?"
 # Since most of the cases when makeboot.sh is run, all the files are in FAT (USB flash drive normally uses FAT), we have to make syslinux executable.
 echo "We need a filesystem supporting Unix file mode for syslinux. Copying syslinux from FAT to /tmp/..."
 syslinux_tmpd="$(mktemp -d /tmp/syslinux.XXXXXX)"
